big5 library

A Dart library for Big5 character encoding and decoding.

This library provides utilities to encode and decode text using the Big5 character encoding, commonly used for Traditional Chinese text. It also provides comparison methods for proper Chinese text collation.

Classes

Big5
A utility class for Big5 character encoding operations.

Constants

encode0High → const int
encode0Low → const int
encode1High → const int
encode1Low → const int
encode2High → const int
encode2Low → const int
encode3High → const int
encode3Low → const int
encode4High → const int
encode4Low → const int
encode5High → const int
encode5Low → const int
encode6High → const int
encode6Low → const int
encode7High → const int
encode7Low → const int
RUNE_ERROR → const int
RUNE_SELF → const int